# Generated by roxygen2: do not edit by hand

S3method(print,tplyr_assoc_test)
S3method(print,tplyr_custom_group)
S3method(print,tplyr_f_str)
S3method(print,tplyr_meta)
S3method(print,tplyr_pop_data)
S3method(print,tplyr_spec)
S3method(print,tplyr_total_group)
export(apply_conditional_format)
export(apply_formats)
export(apply_row_masks)
export(as_display)
export(assoc_test)
export(collapse_row_labels)
export(custom_group)
export(f_str)
export(generate_row_ids)
export(get_data_labels)
export(group_analyze)
export(group_count)
export(group_desc)
export(group_shift)
export(is_pop_data)
export(is_tplyr_layer)
export(is_tplyr_spec)
export(label)
export(layer_settings)
export(pop_data)
export(proportion_ci)
export(replace_leading_whitespace)
export(str_extract_num)
export(str_indent_wrap)
export(total_group)
export(tplyr2_options)
export(tplyr_build)
export(tplyr_from_ard)
export(tplyr_header_n)
export(tplyr_layers)
export(tplyr_meta)
export(tplyr_meta_result)
export(tplyr_meta_subset)
export(tplyr_numeric_data)
export(tplyr_read_spec)
export(tplyr_spec)
export(tplyr_stats_data)
export(tplyr_to_ard)
export(tplyr_write_spec)
import(data.table)
importFrom(purrr,discard)
importFrom(purrr,imap)
importFrom(purrr,iwalk)
importFrom(purrr,keep)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_chr)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,pmap_chr)
importFrom(purrr,walk)
importFrom(rlang,`%||%`)
importFrom(stats,IQR)
importFrom(stats,as.formula)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stringr,`str_sub<-`)
importFrom(stringr,fixed)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_glue)
importFrom(stringr,str_length)
importFrom(stringr,str_locate)
importFrom(stringr,str_locate_all)
importFrom(stringr,str_match_all)
importFrom(stringr,str_pad)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_subset)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_trim)
importFrom(stringr,str_wrap)
importFrom(utils,head)
importFrom(utils,tail)
